pub struct SessionName(String);Tuple Fields
0: StringTrait Implementations
Sourceimpl Archive for SessionNamewhere
String: Archive,
impl Archive for SessionNamewhere
String: Archive,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedSessionName
type Archived = ArchivedSessionName
The archived representation of this type. Read more
Sourcetype Resolver = SessionNameResolver
type Resolver = SessionNameResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl AsRef<str> for SessionName
impl AsRef<str> for SessionName
Sourceimpl Clone for SessionName
impl Clone for SessionName
Sourcefn clone(&self) -> SessionName
fn clone(&self) -> SessionName
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SessionName
impl Debug for SessionName
Sourceimpl Default for SessionName
impl Default for SessionName
Sourceimpl<'de> Deserialize<'de> for SessionName
impl<'de> Deserialize<'de> for SessionName
Sourcefn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<D> Deserialize<SessionName, D> for ArchivedSessionNamewhere
D: Fallible + ?Sized,
D::Error: Source,
impl<D> Deserialize<SessionName, D> for ArchivedSessionNamewhere
D: Fallible + ?Sized,
D::Error: Source,
Sourcefn deserialize(&self, deserializer: &mut D) -> Result<SessionName, D::Error>
fn deserialize(&self, deserializer: &mut D) -> Result<SessionName, D::Error>
Deserializes using the given deserializer
Sourceimpl Display for SessionName
impl Display for SessionName
impl Eq for SessionName
Sourceimpl FromStr for SessionName
impl FromStr for SessionName
Sourceimpl Hash for SessionName
impl Hash for SessionName
Sourceimpl PartialEq for SessionName
impl PartialEq for SessionName
Sourceimpl Serialize for SessionName
impl Serialize for SessionName
Sourceimpl<__S: Fallible + ?Sized> Serialize<__S> for SessionNamewhere
String: Serialize<__S>,
impl<__S: Fallible + ?Sized> Serialize<__S> for SessionNamewhere
String: Serialize<__S>,
impl StructuralPartialEq for SessionName